cache_ring_bytes_per_token

Function cache_ring_bytes_per_token 

pub fn cache_ring_bytes_per_token(cfg: &ModelConfig) -> usize
Portion of cache_bytes_per_token whose physical row count is capped by the Step35 SWA ring. Zero with the flag off and for every non-Step35 architecture.