pub fn pp2_overlap_resolve(v: Option<&str>, mode: DualPpMode) -> boolExpand description
Pure resolution for MEMRA_PP_OVERLAP, split from the env read for the flip regression tests.
pub fn pp2_overlap_resolve(v: Option<&str>, mode: DualPpMode) -> boolPure resolution for MEMRA_PP_OVERLAP, split from the env read for the flip regression tests.