StreamBufs

Struct StreamBufs 

pub struct StreamBufs {
    pub vtok_d: CudaSlice<u32>,
    pub brk_d: CudaSlice<u32>,
    pub pend_d: CudaSlice<u32>,
    pub last_pred_d: CudaSlice<u32>,
    pub pos_ctr: CudaSlice<i32>,
    pub pos_start_d: CudaSlice<i32>,
    pub ring_d: CudaSlice<u32>,
    pub acc_d: CudaSlice<u32>,
    pub m_rounds: usize,
    pub k: usize,
}

Fields

vtok_d: CudaSlice<u32>

assembled verify tokens [k+1]

brk_d: CudaSlice<u32>

p-min break markers [2]

pend_d: CudaSlice<u32>

pending (bonus-fold) token [1]

last_pred_d: CudaSlice<u32>

last verify prediction [1]

pos_ctr: CudaSlice<i32>

device position counter (rope/append base)

pos_start_d: CudaSlice<i32>

round-start position (rollback anchor)

ring_d: CudaSlice<u32>

committed-token ring [m*(k+1)+1] (slot 0 = count)

acc_d: CudaSlice<u32>

device accept counters [2]

m_rounds: usizek: usize

Implementations

Source

impl StreamBufs

pub fn new( e: &Engine, k: usize, m_rounds: usize, ) -> Result<Self, Box<dyn Error>>

pub fn drain_ring(&self, e: &Engine) -> Result<Vec<u32>, Box<dyn Error>>

Drain the ring after a burst (THE one host sync per M rounds): returns the committed tokens in order and resets nothing — the caller zeroes the ring count for the next burst via e.set_u32_one(&mut ring_d, 0).