memra-engine 0.128.0

From-scratch CUDA LLM inference engine for NVIDIA RTX 50-series (sm_120a) and Hopper (sm_90a) - custom kernels, no frameworks
docs.rs failed to build memra-engine-0.128.0
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.
Visit the last successful build: memra-engine-0.126.1

memra engine: Stage-1 correctness-first forward-pass kernels + ops, on sm_120 via cudarc.