pub struct PreparedStepGroupedExpertParallelGate { /* private fields */ }Expand description
Prepared official Step expert-owner grouped-FP8 projection gate.
Route partitioning, owner-local CSR uploads, input dispatch, activation buffers, and grouped workspaces are persistent. Projection rows are scattered back to canonical pair order only after every owner has completed its rank-local program.
Implementations
Sourceimpl PreparedStepGroupedExpertParallelGate
impl PreparedStepGroupedExpertParallelGate
pub fn tokens(&self) -> usize
pub fn pairs(&self) -> usize
pub fn max_tokens(&self) -> usize
pub fn input_width(&self) -> usize
pub fn expert_width(&self) -> usize
pub fn set_activation_limit(&mut self, limit: Option<f32>) -> Result<(), String>
pub fn active_owners(&self) -> usize
pub fn owner_pair_counts(&self) -> Vec<usize>
pub fn generation(&self) -> u64